==> nextcloud-13.0.1.tgz: nextcloud/apps/files/l10n/ar.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
    "Storage invalid" : "وحدة تخزين غير صالحة",
    "Unknown error" : "خطأ غير معروف",
    "All files" : "كل الملفات",
    "Recent" : "الأخيرة",
    "File could not be found" : "الملف غير موجود",
    "Home" : "الرئيسية",
    "Close" : "إغلاق",
    "Favorites" : "المفضلة ",
    "Could not create folder \"{dir}\"" : "لا يمكن إنشاء المجلد \"{dir}\"",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، انت تقوم برفع {size1} ولكن المساحه المتوفره هي {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "المجلد المطلوب \"{dir}\" غير موجود بعد الان",
    "Not enough free space" : "لا يوجد مساحة تخزينية كافية",
    "Uploading …" : "جاري الرفع...",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} من {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "المجلد المراد غير موجود بعد الان",
    "Error when assembling chunks, status code {status}" : "خطأ عند تجميع القطع، حالة الخطأ {status}",
    "Actions" : "* تطبيقات.\n* أنشطة.",
    "Download" : "تنزيل",
    "Rename" : "إعادة التسمية",
    "Move or copy" : "إنقل أو انسخ",
    "Target folder" : "المجلد الهدف",
    "Delete" : "حذف ",
    "Disconnect storage" : "قطع اتصال التخزين",
    "Unshare" : "إلغاء المشاركة",
    "Could not load info for file \"{file}\"" : "لم يستطع تحميل معلومات الملف \"{file}\"",
    "Files" : "الملفات",
    "Details" : "تفاصيل",
    "Select" : "اختار",
    "Pending" : "قيد الانتظار",
    "Unable to determine date" : "تعذر تحديد التاريخ",
    "This operation is forbidden" : "هذة العملية ممنوعة ",
    "This directory is unavailable, please check the logs or contact the administrator" : "هذا المجلد غير متوفر, الرجاء مراجعة سجل الأخطاء أو الاتصال بمدير النظام",
    "Could not move \"{file}\", target exists" : "لا يمكن نقل  \"{file}\", الملف موجود بالفعل هناك",
    "Could not move \"{file}\"" : "لا يمكن نقل \"{file}\"",
    "Could not copy \"{file}\", target exists" : "لم يستطع نسخ \"{file}\"، المستهدف موجود",
    "Could not copy \"{file}\"" : "لم يستطع نسخ \"{file}\"",
    "Copied {origin} inside {destination}" : "منسوخ {origin} داخل {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "منسوخ {origin} و {nbfiles} ملفات اخرى داخل {destination}",
    "{newName} already exists" : "{newname} موجود مسبقاً",
    "Could not rename \"{fileName}\", it does not exist any more" : "لا يمكن اعادة تسمية \"{fileName}\", لانه لم يعد موجود",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{targetName}\" مستخدم من قبل في المجلد \"{dir}\". الرجاء اختيار اسم اخر.",
    "Could not rename \"{fileName}\"" : "إعادة تسمية الملف \"{fileName}\" لم تنجح",
    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "لا يمكن إنشاء الملف \"{file}\" فهو موجود بالفعل",
    "Could not create folder \"{dir}\" because it already exists" : "لا يمكن إنشاء المجلد \"{dir}\" فهو موجود بالفعل",
    "Error deleting file \"{fileName}\"." : "خطأ أثناء حذف الملف \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "لا نتائج بحث في مجلدات اخرى ل {tag}{filter}{endtag}",
    "Name" : "اسم",
    "Size" : "حجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا يوجد مجلدات %n","1 مجلد %n","2 مجلد %n","عدد قليل من مجلدات %n","عدد كبير من مجلدات %n","مجلدات %n"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","ملف %n","2 ملف %n","قليل من ملفات %n","الكثير من ملفات %n"," ملفات %n"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "_including %n hidden_::_including %n hidden_" : ["يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي"],
    "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
    "New" : "جديد",
    "{used} of {quota} used" : "{used} من {quota} مستخدم",
    "{used} used" : "{used} مستخدم",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "\"/\" is not allowed inside a file name." : "\"/\" غير مسموح في تسمية الملف",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" أنه نوع ملف غير مسموح",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "مساحة تخزين {owner} ممتلئة، لا يمكن تحديث الملفات او مزامنتها بعد الان !",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "المساحة التخزينية لـ {owner} ممتلئة تقريبا ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
    "View in folder" : "اعرض في المجلد",
    "Copied!" : "نسخت!",
    "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط لـ المستخدمين الذين يمكنهم  الولوج الى هذا الملف/الفايل)",
    "Path" : "المسار",
    "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%nبايت"],
    "Favorited" : "المفضلة",
    "Favorite" : "المفضلة",
    "New folder" : "مجلد جديد",
    "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث tags",
    "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
    "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
    "File handling" : "التعامل مع الملف",
    "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
    "max. possible: " : "الحد الأقصى المسموح به",
    "Save" : "حفظ",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "باستخدام PHP-FPM قد يستغرق 5 دقائق لتطبيق التغيرات.",
    "Settings" : "الإعدادات",
    "Show hidden files" : "عرض الملفات المخفية",
    "WebDAV" : "WebDAV",
    "No files in here" : "لا يوجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
    "Text file" : "ملف نصي",
    "New text file.txt" : "ملف نصي جديد fille.txt"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-16.0.5.tgz: nextcloud/apps/files/l10n/ar.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
    "Storage invalid" : "وحدة تخزين غير صالحة",
    "Unknown error" : "خطأ غير معروف",
    "All files" : "كل الملفات",
    "Recent" : "الحديثة",
    "Favorites" : "المفضلة ",
    "File could not be found" : "الملف غير موجود",
    "Move or copy" : "إنقل أو انسخ",
    "Download" : "تنزيل",
    "Delete" : "حذف ",
    "Home" : "الرئيسية",
    "Close" : "إغلاق",
    "Could not create folder \"{dir}\"" : "لا يمكن إنشاء المجلد \"{dir}\"",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، إنك بصدد رفع {size1} ولكن المساحة المتبقية المتوفرة تبلُغ {size2}",
    "Target folder \"{dir}\" does not exist any more" : "المجلد المطلوب \"{dir}\" غير موجود بعد الان",
    "Not enough free space" : "لا يوجد مساحة تخزينية كافية",
    "Uploading …" : "جاري الرفع...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} من {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "المجلد المراد غير موجود بعد الان",
    "Error when assembling chunks, status code {status}" : "خطأ عند تجميع القطع، حالة الخطأ {status}",
    "Actions" : "الإجراءات",
    "Rename" : "إعادة التسمية",
    "Copy" : "نسخ",
    "Open" : "افتح",
    "Disconnect storage" : "قطع اتصال التخزين",
    "Unshare" : "إلغاء المشاركة",
    "Could not load info for file \"{file}\"" : "لم يستطع تحميل معلومات الملف \"{file}\"",
    "Files" : "الملفات",
    "Details" : "التفاصيل",
    "Select" : "إختر",
    "Pending" : "قيد الانتظار",
    "Unable to determine date" : "تعذر تحديد التاريخ",
    "This operation is forbidden" : "هذة العملية ممنوعة ",
    "This directory is unavailable, please check the logs or contact the administrator" : "هذا المجلد غير متوفر, الرجاء مراجعة سجل الأخطاء أو الاتصال بمدير النظام",
    "Could not move \"{file}\", target exists" : "لا يمكن نقل  \"{file}\", الملف موجود بالفعل هناك",
    "Could not move \"{file}\"" : "لا يمكن نقل \"{file}\"",
    "copy" : "أنسخ",
    "Could not copy \"{file}\", target exists" : "لم يستطع نسخ \"{file}\"، المستهدف موجود",
    "Could not copy \"{file}\"" : "لم يستطع نسخ \"{file}\"",
    "Copied {origin} inside {destination}" : "منسوخ {origin} داخل {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "منسوخ {origin} و {nbfiles} ملفات اخرى داخل {destination}",
    "{newName} already exists" : "{newname} موجود مسبقاً",
    "Could not rename \"{fileName}\", it does not exist any more" : "لا يمكن اعادة تسمية \"{fileName}\", لانه لم يعد موجود",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{targetName}\" مستخدم من قبل في المجلد \"{dir}\". الرجاء اختيار اسم اخر.",
    "Could not rename \"{fileName}\"" : "إعادة تسمية الملف \"{fileName}\" لم تنجح",
    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "لا يمكن إنشاء الملف \"{file}\" فهو موجود بالفعل",
    "Could not create folder \"{dir}\" because it already exists" : "لا يمكن إنشاء المجلد \"{dir}\" فهو موجود بالفعل",
    "Error deleting file \"{fileName}\"." : "خطأ أثناء حذف الملف \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "لا نتائج بحث في مجلدات اخرى ل {tag}{filter}{endtag}",
    "Name" : "الإسم",
    "Size" : "الحجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا يوجد مجلدات %n","1 مجلد %n","2 مجلد %n","عدد قليل من مجلدات %n","عدد كبير من مجلدات %n","مجلدات %n"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","ملف %n","2 ملف %n","قليل من ملفات %n","الكثير من ملفات %n"," ملفات %n"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "_including %n hidden_::_including %n hidden_" : ["يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي"],
    "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
    "New" : "جديد",
    "{used} of {quota} used" : "{used} من {quota} مستخدم",
    "{used} used" : "{used} مستخدم",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "\"/\" is not allowed inside a file name." : "\"/\" غير مسموح في تسمية الملف",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" أنه نوع ملف غير مسموح",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "مساحة تخزين {owner} ممتلئة، لا يمكن تحديث الملفات او مزامنتها بعد الان !",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "المساحة التخزينية لـ {owner} ممتلئة تقريبا ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
    "View in folder" : "اعرض في المجلد",
    "Copied!" : "نسخت!",
    "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط لـ المستخدمين الذين يمكنهم  الولوج الى هذا الملف/الفايل)",
    "Path" : "المسار",
    "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%nبايت"],
    "Favorited" : "المفضلة",
    "Favorite" : "المفضلة",
    "New folder" : "مجلد جديد",
    "Upload file" : "رفع ملف",
    "Remove from favorites" : "إزالته مِن المفضلة",
    "Add to favorites" : "إضافة إلى المفضلة",
    "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث tags",
    "Added to favorites" : "تمت إضافته إلى المفضلة",
    "Removed from favorites" : "تمت إزالته مِن المفضلة",
    "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
    "Unlimited" : "غير محدود",
    "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
    "File Management" : "إدارة الملفات",
    "%s used" : "%s مُستخدَم",
    "Settings" : "الإعدادات",
    "Show hidden files" : "عرض الملفات المخفية",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "استخدم هذا العنوان قصد <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">الوصول إلى ملفاتك على WebDAV</a>",
    "No files in here" : "لا يوجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "No favorites yet" : "ليست عندك مفضلات بعد",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
    "Tags" : "الوسوم",
    "Deleted files" : "الملفات المحذوفة",
    "Shares" : "التي قمتَ بمشاركتها",
    "Shared with others" : "شاركته مع الاخرين",
    "Shared by link" : "شاركته باستخدام رابط مشاركة",
    "Text file" : "ملف نصي",
    "New text file.txt" : "ملف نصي جديد fille.txt",
    "File handling" : "التعامل مع الملف",
    "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
    "max. possible: " : "الحد الأقصى المسموح به",
    "Save" : "حفظ",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "باستخدام PHP-FPM قد يستغرق 5 دقائق لتطبيق التغيرات.",
    "Cancel upload" : "إلغاء الرفع"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
